@@ -22,10 +22,12 @@ var (
 			infos.FunctionColumnsNumericPrecRadix: "10",
 			infos.ConstraintIsDeferrable:          "''",
 			infos.ConstraintInitiallyDeferred:     "''",
+			infos.PrivilegesGrantor:               "''",
 			infos.ConstraintJoinCond:              "AND r.table_name = f.table_name",
 		}),
 		infos.WithSystemSchemas([]string{"mysql", "information_schema", "performance_schema", "sys"}),
 		infos.WithCurrentSchema("COALESCE(DATABASE(), '%')"),
+		infos.WithUsagePrivileges(false),
 	)
 	// NewCompleter for MySQL databases
 	NewCompleter = func(db drivers.DB, opts ...completer.Option) readline.AutoCompleter {
